<?php

/**
 * @file
 * flag_hide.admin.inc
 * Displays, submits and saves the form for the admin configuration page.
 */

/**
 * Menu callback for admin settings.
 */
function flag_hide_admin_config() {
  $form = array();
  $form['flag_hide_node'] = array(
    '#type' => 'fieldset',
    '#title' => t('Configuration for nodes'),
    '#description' => t('These node configuration options, if used, require the <a href="@href" target="project">Flag</a> module.', array(
      '@href' => url('http://drupal.org/project/flag')
    ))
  );
  $form['flag_hide_node']['flag_hide_method'] = array(
    '#type' => 'radios',
    '#title' => t('Method used to hide node content'),
    '#default_value' => variable_get('flag_hide_method', FLAG_HIDE_METHOD_DEFAULT),
    '#options' => array(
      FLAG_HIDE_METHOD_DEFAULT => t('default, no files required'),
      FLAG_HIDE_METHOD_TEMPLATE_SUGGESTION => t('via the file <em>node--hide.tpl.php</em>, added to your theme'),
    ),
    '#description' => t("If you select the second method you must place <em>node--hide.tpl.php</em> in the same directory as your theme's node.tpl.php.<br/> <em>node--hide.tpl.php</em> may be empty or may contain some message with or without rendered variables."),
  );
  $form['flag_hide_node']['flag_hide_node_placeholder'] = array(
    '#type' => 'textfield',
    '#size' => 128,
    '#title' => t('Text to replace node content when hidden'),
    '#default_value' => variable_get('flag_hide_node_placeholder', FLAG_HIDE_NODE_PLACEHOLDER),
    '#description' => t('<strong>Example</strong>: "%msg"<br/> Some HTML tags are allowed. Blank out this field and untick the box below to leave no trace of hidden content.', array(
      '%msg' => FLAG_HIDE_NODE_PLACEHOLDER)
    ),
    '#states' => array(
      'invisible' => array(
        'input[name="flag_hide_method"]' => array(
          'value' => FLAG_HIDE_METHOD_TEMPLATE_SUGGESTION,
        ),
      ),
    ),
  );
  $form['flag_hide_node']['flag_hide_node_display_unhide_link'] = array(
    '#type' => 'checkbox',
    '#title' => t('When node content is hidden, display an <em>unhide</em> link'),
    '#default_value' => variable_get('flag_hide_node_display_unhide_link', FALSE),
    '#description' => t(''),
    '#states' => array(
      'invisible' => array(
        'input[name="flag_hide_method"]' => array(
          'value' => FLAG_HIDE_METHOD_TEMPLATE_SUGGESTION,
        ),
      ),
    ),
  );
  $form['flag_hide_node']['flag_hide_node_title'] = array(
    '#type' => 'checkbox',
    '#title' => t('Also hide page title when node content is hidden'),
    '#default_value' => variable_get('flag_hide_node_title', FALSE),
    '#description' => t('This applies to <em>node/*</em> pages.'),
  );

  $form['flag_hide_node']['pages'] = array(
    '#type' => 'markup',
    '#prefix' => '<div class="pages">',
    '#suffix' => '</div>',
  );
  $form['flag_hide_node']['pages']['flag_hide_include_pages'] = array(
    '#type' => 'textarea',
    '#rows' => 3,
    '#title' => t('Pages on which hiding of nodes should be enabled'),
    '#default_value' => variable_get('flag_hide_include_pages', FLAG_HIDE_DEFAULT_PAGE_INCLUSIONS),
    '#description' => t("Enter relative paths, one per line. Do not start with a slash. You may use path aliases. The asterisk <em>*</em> is the wildcard character, i.e. <em>admin/*</em> denotes all pages that have a path starting with <em>admin/</em>"),
  );
  $form['flag_hide_node']['pages']['flag_hide_exclude_pages'] = array(
    '#type' => 'textarea',
    '#rows' => 3,
    '#title' => t('Exceptions: pages excluded from the set on the left'),
    '#default_value' => variable_get('flag_hide_exclude_pages', FLAG_HIDE_DEFAULT_PAGE_EXCLUSIONS),
    '#description' => t('As before, one relative path per line.'),
  );
  
  $form['flag_hide_blocks'] = array(
    '#type' => 'fieldset',
    '#title' => t('Configuration for blocks'),
  );
  $form['flag_hide_blocks']['flag_hide_enable_block_hiding'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable hiding of empty blocks'),
    '#default_value' => variable_get('flag_hide_enable_block_hiding', FALSE),
    '#description' => t('This adds to each block configuration page a check box for removing title and HTML of blocks containing no text or images, after flagging or otherwise.<br/> To activate this option, click the vertical tab <strong>Dynamic conditions</strong> on the block configuration form.'),
  );

  $form['flag_hide_views'] = array(
    '#type' => 'fieldset',
    '#title' => t('Configuration for Views'),
  );
  $form['flag_hide_views']['flag_hide_empty_view_title'] = array(
    '#type' => 'checkbox',
    '#title' => t('Hide title of empty Views'),
    '#default_value' => variable_get('flag_hide_empty_view_title', FALSE),
    '#description' => t('This removes the title from any View output that contains no text or images.'),
  );

  $form['#attached']['css'][] = drupal_get_path('module', 'flag_hide') . '/css/flag_hide.admin.css';

  $form['actions']['#type'] = 'actions';
  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save configuration'),
  );
  $form['#submit'][] = 'flag_hide_admin_config_submit';
  $form['#theme'] = 'system_settings_form';
  return $form;
}

/**
 * Form submit handler for flag_hide_admin_config().
 *
 * @param array $form
 * @param array $form_state
 */
function flag_hide_admin_config_submit($form, &$form_state) {

  // Clear out the form with stuff we do not wish to save, like buttons.
  form_state_values_clean($form_state);

  $allowed_html_tags = array('a', 'br', 'p', 'em', 'strong', 'cite', 'blockquote', 'code', 'ul', 'ol', 'li', 'dl', 'dt', 'dd');
  $form_state['values']['flag_hide_node_placeholder'] = filter_xss($form_state['values']['flag_hide_node_placeholder'], $allowed_html_tags);

  foreach ($form_state['values'] as $key => $value) {
    variable_set($key, $value);
  }
  drupal_theme_rebuild();

  drupal_set_message(t('The configuration options have been saved.'));
}

